/*

RC Bruder Conversion Radmitnehmer, der das Rad des Cat Skid Steer mit dem Servoarm verbindet.

Die Idee ist, die Original-Räder von der Achse zu lösen. Die Achse kommt in die Tonne (Oder besser: Reste-Kiste :) ). Dann die Räder innen mit 20-30g Bleikugeln anfüllen, den Rest mit Epoxy auffüllen. Mit dem Epoxy dann auch diesen Radmitnehmer einkleben. Verschraubt wird durch die innere Bohrung von außen mit einer langen 2.5mm Schraube, die direkt in den Servo geht. Dazu muss im Rad die Felgenversteifungen entfernt werden. (tbd)

Montageanleitung:
- Achse von Felge entfernen
- 10mm Loch durch Felge (mittig! hinterher nicht/kaum korrigierbar) bohren passend für Rörchen - von innen bohren, damit es mittig wird
- Röhrchen einstecken, und einkleben (ggf. ablängen)
- Blei einfüllen (20-30g?)
- Epoxy einfüllen
- Mitnehmerplatte einkleben
- Servoarm auf Mitnehmerplatte schrauben, auf Rundlauf achten
- Bauteil auf Servo stecken
- 2.5mm Schraube durch die Felge/Röhrchen stecken und mit Servo verschrauben (U-Scheibe nötig? GGf. Kappe designen)
- GGf. Rundlauf korrigieren

Ideen: Der Mitnehmer könnte auch ähnlich einer echten Felge/Mitnehmers am 1:1er von außen mit 4-6 Schrauben mit der Felge verschraubt werden. Dann könnte die Zentrierung dort stattfinden. Anbringen von Blei dann nicht möglich?

ToDo:
- serious refactoring :)
- remove all the denglisch
- publish

*/

/* Modules */
include <../Modules/Module_Geometrical_Objects.scad>;

/* Globals */
//$fn=23;
//$fn=42;
$fn=84;

/* Customize this... */
gMS=2.0;
gMSMin=1.0;
gRadmitnehmerDurchmesser=39; // Damit sollte es mittig im Rad sitzen - ggf. kleiner machen zum einfacheren zentrieren?
gRadmitnehmerStaerke=gMS; //2.4+2;
//gRadAchseDurchmesser=gRadmitnehmerDurchmesser;
//gRadAchseDurchmesser=16.0;
//gRadAchseHoehe=5.0;
//gWellenDuchmesser=4.0+0.6; //4mm-Welle
//gWellenDuchmesser=8.0+0.6; //Mitnehmer
//gHexSize=12.2;
//gHexHeight=6.0;
gScrewDia=1.5; // should fit some small screws in your parts box :)...
//gScrewOffset=15; // set according to your servo horn
//echo("ScrewOffset (offset from middle of servo horn): " , gScrewOffset);

//langLoch3D(10, 30, 5);


/* Röhrchen, durch das dann die Verschraubung mit dem Servo geht */
//gBohrungDia=2.5+1.0; // 2.5mm sollte für die Schraube reichen. Da der Drucker bei so kleinen Radien aber sehr ungenau ist -> "Spiel" einplanen
gBohrungDia=10.0-gMSMin*2; // Deutlich größer als der Schraubenkopf machen, außerdem muss der Schraubendreher durchpassen
gBohrungHeight=8; // "Tiefe" des Röhrchens - also die Felgenbreite abzgl. Servohorn und was vom Servo noch in die Felge ragen soll
gBohrungDiaOuter=gBohrungDia+2*gMSMin;
echo("Bohrung für Roehrchen: ", gBohrungDiaOuter, " mm");
if (1)
translate([-gRadmitnehmerDurchmesser*0.66-gBohrungDia/2, 0, 0])
difference()
{
	cylinder(d=gBohrungDiaOuter, h=gBohrungHeight); // Viel Material einplanen, falls ein Aufbohren wg. Rundlaufkorrektur nötig
	cylinder(d=gBohrungDia, h=gBohrungHeight);
}

/* Kappe für das Röhrchen */
gKappeHeight=10;
if (0)
translate([+gRadmitnehmerDurchmesser*0.66+gBohrungDiaOuter/2, 0, 0])
{
	union()
	{
		difference()
		{
			/* outer hull (cone) */
			union()
			{
				cylinder(d1=gBohrungDiaOuter, d2=gBohrungDia+gMS, h=gKappeHeight);
				cylinder(d=gBohrungDiaOuter+2*gMS, h=gMS);
			} // union
			
			/* hole for screwdriver 
			cylinder(d=gBohrungDia, h=gBohrungHeight); */
		
			/* Room for the wheelnuts */	
			for (r=[0:60:360])
			{
				rotate([0, 0, r])
				translate([gBohrungDiaOuter/2+gMS/3, 0, gMS])
				cylinder(d=2.0*1.5, h=gKappeHeight);
			}
		} // diff

		/* Wheelnuts */
		for (r=[0:60:360])
		{
			rotate([0, 0, r])
			translate([gBohrungDiaOuter/2+gMS/3, 0, gMS])
			hexHub(2.0, gMS/2);
		}

		translate([0, 0, gKappeHeight])
		hexHub(gBohrungDia-gMS*1, gMS/2);
	} // union
} // if


/* Mitnehmer */
if (1)
{
	gSpace=0.2; // Luft zum Einkleben des Röhrchens
	difference()
	{
		union()
		{
			/* Rad-Halteplatte mit 6 Schrauben am Rad zu befestigen */
			cylinder(d=gRadmitnehmerDurchmesser, h=gRadmitnehmerStaerke);
			
			/* Mitnehmer-Aufnahme */
			if (0)
			translate([0, 0, gRadmitnehmerStaerke])
			cylinder(d=gRadAchseDurchmesser, h=gRadAchseHoehe);
		} // union

		/* Loch für die Verschraubung (bzw. den Schraubendreher) */
		cylinder(d=gBohrungDiaOuter+2*gSpace, h=gRadmitnehmerStaerke);

		/* Radmitnehmer */
		if (0) // brauchen keinen Hex-hier muss der Servoarm dran!
		translate([0, 0, gRadmitnehmerStaerke+gRadAchseHoehe-gHexHeight])
		hexHub(gHexSize, gHexHeight);
		
		/* Bohrungen für die Verschraubung mit dem Servohorn (Kreuz oder Scheibe) */
		for (screwOffset=[15, 20, 25, 30])
		for (a=[0:45:360])
		{
			rotate([0, 0, a])
			translate([screwOffset/2, 0, 0])
			cylinder(d=gScrewDia, h=gRadmitnehmerStaerke);
		}
	} // diff
}



















